beautifulsoup4: A screen-scraping library
=========================================

Description
-----------

Screen-scraping library

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/beautifulsoup4/

https://www.crummy.com/software/BeautifulSoup/
